import * as React from 'react';
import {makeStyles, Typography} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {ButtonField, InputField, PaddedPaper} from "@rx-suite/ui";
import {routerStore} from "@rx-suite/data";
import {OrderStore} from "../../stores/OrderStore";

const useClasses = makeStyles((theme) => ({
    errorMessage: {
        color: theme.palette.error.main
    }
}));

type Props = {
    title: string,
    label: string,
    param: string
}
export const LookupForm: React.FunctionComponent<Props> = ({ title, label, param }) => {
    const [ value, setValue ] = React.useState("");
    const [ errorMessage, setErrorMessage ] = React.useState("");
    const [ loading, setLoading ] = React.useState(false);
    const classes = useClasses();

    const handleChange = React.useCallback((e) => {
        setErrorMessage("");
        setValue(e.target.value);
    }, []);

    const handleClick = React.useCallback(async () => {
        setLoading(true);
        const response = await fetch(`/api/order_lookups`, {
            method: "POST",
            body: JSON.stringify({
                [param]: value
            }),
            headers: {
                "Content-Type": "application/json"
            }
        });
        const json = await response.json();
        if(response.ok) {
            routerStore.history.push(OrderStore.readLink(json.id));
        } else {
            setErrorMessage(json.error);
        }

        setLoading(false);


    }, [param, value]);

    return(
        <PaddedPaper>
            <Typography variant={"h6"}><Trans>{title}</Trans></Typography>
            <InputField
                label={label}
                value={value}
                onChange={handleChange}
                disabled={loading}
            />
            <ButtonField
                text={t`Submit`}
                onClick={handleClick}
                loading={loading}
                disabled={value.length === 0}
            />
            <Typography variant={"subtitle1"} className={classes.errorMessage}>{errorMessage}</Typography>
        </PaddedPaper>
    )
}