import * as React from 'react';
import { observer } from 'mobx-react-lite';
import {
    communicateWithModule,
    ModelInput,
    useModelContext,
    AsyncSelectField, useModelFieldProps
} from "@rx-suite/ui";
import {OrderFieldProps, sortedOptions} from "../../../stores/_FieldConstants";
import {SelectOption} from "react-select-material-ui";
import debounceAsync from 'debounce-async';
import {t} from "@lingui/macro";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";

const fn = async (query: string, prevOptions: SelectOption[], additional: any) => {
    const response = await communicateWithModule("rxuniverse_api", "/api/frames/traces", {
        "first-key": query,
        limit: 10,
        offset: additional.page * 10,
        "include-ftd-inv": "N"
    });
    const newOptions: SelectOption[] = [];

    response.models.forEach((o: { name: string }) => {
        const exists = prevOptions.some(p => p.value === o.name);
        if(!exists) {
            newOptions.push({ value: o.name, label: o.name as string })
        }
    })

    return({
        options: sortedOptions(newOptions),
        hasMore: response.count > prevOptions.length,
        additional: {
            ...additional,
            page: additional.page + 1
        }
    })
}


export const FrameTraceFields: React.FunctionComponent<OrderFieldProps> = observer(({name, label}) => {
    const store = useOrderEntryStore();
    const readOnly = store.shouldLockFrameFields;
    const model = useModelContext();
    const loadOptions = React.useCallback(debounceAsync(fn, 320), [])
    const fieldProps = useModelFieldProps({ name, label: t`Frame Trace` });
    const traceId = model.viewModel.dig(name);
    const resolvedLabel = !!store.frameTraceFile || !traceId  ? t`No trace used` : label;

    const handleChange = React.useCallback((name, value) => {
        const traceID = value == '' ? null : value;
        model.handleSelectChange(name, traceID);
        store.setOrderTraceID(traceID);
        if(traceID){
            store.getTrace();
        } else {
            store.resetTrace();
        }
    }, [model]);

    if(readOnly || !!store.frameTraceFile) {
        return(
            <ModelInput name={name} label={resolvedLabel}></ModelInput>
        )
    } else {
        return(
            <AsyncSelectField
                loadOptions={loadOptions}
                clearable
                fullWidth
                defaultOptions={[{value: traceId, label: traceId}]}
                {...fieldProps}
                onChange={handleChange}
                value={traceId}
            />
        )
    }
})