import * as React from 'react';
import {observer} from "mobx-react-lite";
import {QuickCodeStore} from "../../../stores/QuickCodeStore";
import {
    AsyncSelectField,
    useModelContext,
    useStoreLoadOptions,
    useReadonlyContext,
    HintButtonProps
} from "@rx-suite/ui";
import {DataStore} from "@rx-suite/data";
import {Model} from "@rx-suite/data/build";
import { t } from '@lingui/macro';
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";

export const QuickCodeSelect = observer(() => {
    const model = useModelContext();
    const store = useOrderEntryStore();
    const readOnly = useReadonlyContext();
    const loadOptions = useStoreLoadOptions(QuickCodeStore as unknown as DataStore<Model>, "code", "displayName", [ { id: "code", desc: false }])
    const hint = {
        title: t`Quick Code`,
        text: t`The code for the lens combination shortcut`} as HintButtonProps;

    const handleSelectFieldChange = React.useCallback((name, value) => {
        if (value) {
            const data = QuickCodeStore.get(value)
            model.viewModel.quick_code_id = value;
            model.viewModel.style_type_id = data?.style_type_id;
            model.viewModel.style_id = data?.style_id;
            model.viewModel.style_material_id = data?.style_material_id;
        } else {
            store.resetLensInformation();
        }
    }, [model.viewModel])

    return (
        <AsyncSelectField
            label={t`Quick Code`}
            onChange={handleSelectFieldChange}
            value={model.viewModel.quick_code_id || null}
            loadOptions={loadOptions}
            disabled={readOnly}
            clearable
            hint={hint}
        />
    )
})