import * as React from 'react';
import {ModelSelect, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ShippingMethodModel, ShippingMethodStore} from '../../../stores/ShippingMethodStore';
import {sortedOptions} from "../../../stores/_FieldConstants";
import { customerSelectionStore } from '../../../hooks/useCustomerSelectionStore';

export const ShippingMethodSelect: React.FunctionComponent = observer(() => {
    const readOnly = useReadonlyContext();
    const order = useModelContext();

    const currentShippingMethodId = order?.viewModel?.shipping_method_id;
    const currentCustomerId = order?.viewModel.dig("customer_id").toString();

    React.useEffect(() => {
        ShippingMethodStore.getData();
    }, []);

    React.useEffect(() => {
        const tmp = async () => {
            if(!order) return;
            if(order.readOnly) return;

            await customerSelectionStore.currentCustomer?.sync();
            const shippingMethodId = customerSelectionStore.currentCustomer?.currentShippingMethodId;

            if(shippingMethodId && !currentShippingMethodId) {
                order.nestedAssignment("shipping_method_id", shippingMethodId.toString());
            } else {
                order.nestedAssignment("shipping_method_id", "");
            }
        }

        if(!readOnly && !order?.viewModel?.isClone) {
            tmp();
        }

    }, [order, currentCustomerId, readOnly]);

    const shipping_methods = ShippingMethodStore.models as ShippingMethodModel[];
    const options = shipping_methods.filter(sm => {
        return sm.description.length > 0;
    }).map(sm => {
        return {
            label: sm.description,
            value: sm.getId().toString()
        }
    });

    console.log(options);
    return (
        <ModelSelect
            name={"shipping_method_id"}
            options={sortedOptions(options)}
            loading={!!customerSelectionStore.currentCustomer?.syncing}
        />
    );
});