import * as React from 'react';
import {ModelSelect, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {OrderModel} from "../../../stores/OrderStore";
import {StyleMaterialModel, StyleMaterialStore} from "../../../stores/StyleMaterialStore";
import {observer} from "mobx-react-lite";
import {sortedOptions} from "../../../stores/_FieldConstants";


type props = {
    disabled: boolean
}
export const StyleMaterialSelect: React.FunctionComponent<props> = observer(({disabled}) => {
    const model = useModelContext() as OrderModel;
    const readOnly = useReadonlyContext();

    React.useEffect(() => {
        model.viewModel.style_material = null;
        if (model.viewModel.style_id) {
            StyleMaterialStore.setFetchParams({
                filtered: [
                    {id: "style_id", value: model.viewModel.style_id}
                ],
                sorted: []
            })
        }
    }, [model.viewModel, model.viewModel.style_id]);

    const styles = StyleMaterialStore.tableData as StyleMaterialModel[];
    const options = styles.map(s => {
        return {
            value: s.getId(),
            label: s.material_description
        }
    })
    const errText = readOnly ? '' : StyleMaterialStore.fetchErr || model.errors.style_material_id;

    return (
        <ModelSelect
            name={"style_material_id"}
            options={sortedOptions(options)}
            loading={StyleMaterialStore.isLoading}
            disabled={disabled || !!model.viewModel.quick_code_id || !model.viewModel.style_id || readOnly}
            error={!!StyleMaterialStore.fetchErr || !!model.errors.style_material_id}
            helperText={errText}
        />
    )
});
