import * as React from 'react';
import {ModelSelect, useModelContext, useReadonlyContext} from "@rx-suite/ui";
import {observer} from 'mobx-react-lite';
import {StyleModel, StyleStore} from "../../../stores/StyleStore";
import {OrderModel} from "../../../stores/OrderStore";
import {sortedOptions} from "../../../stores/_FieldConstants";

type props = {
    disabled: boolean
}
export const StylesSelect: React.FunctionComponent<props> = observer(({disabled}) => {
    const model = useModelContext() as OrderModel;
    const readOnly = useReadonlyContext();

    React.useEffect(() => {
        if (model.viewModel.style_type_id) {
            const filtered = [
                {id: "style_type_id", value: model.viewModel.style_type_id}
            ];
            if (model.viewModel._fstatus === "U") {
                filtered.push({id: "requires_trace", value: "false"});
            }
            StyleStore.setFetchParams({
                filtered,
                sorted: []
            })
        }
    }, [model.viewModel.quick_code_id, model.viewModel.style_type_id, model.viewModel._fstatus]);

    const styles = StyleStore.tableData as StyleModel[];
    const options = styles.map(s => {
        return {
            value: s.getId(),
            label: s.description
        }
    });
    return (
        <ModelSelect
            name={"style_id"}
            options={sortedOptions(options)}
            loading={StyleStore.isLoading}
            disabled={disabled || !!model.viewModel.quick_code_id || !model.viewModel.style_type_id || readOnly}
            error={!!StyleStore.fetchErr || !!model.errors.style_id}
            helperText={StyleStore.fetchErr || model.errors.style_id}
        />
    )
})