import {observer} from 'mobx-react-lite';
import * as React from 'react';
import {t} from "@lingui/macro";
import {useOrderEntryStore} from "../../../hooks/useOrderEntryStore";
import LoadingOverlay from "react-loading-overlay";
import { ReadonlyProvider } from "@rx-suite/ui";
import {FormHelperText } from "@material-ui/core";
import {useSnackbar} from "notistack";

export const FrameWrapper = observer(({children}) => {
    const store = useOrderEntryStore();
    const {enqueueSnackbar} = useSnackbar();
    const fetchingFrameCandidatesError = store.fetchingFrameCandidatesError;
    const fetchingFrameTraceError = store.fetchingFrameTraceError;

    console.log('iam mounted');

    React.useEffect(() => {
        store.clearErrors();
    }, []);

    React.useEffect(() => {
        if(store.mustPickFrame && !store.isUsingFrame){
            store.resetTraceId();
            store.clearFrameMeasurements();
        }
    }, [store, store.mustPickFrame, store.isUsingFrame, store.resetTraceId, store.clearFrameMeasurements]);

    React.useEffect(() => {
        if(store.order?.traceID == ""){
            store.resetTraceId();
        }
    }, [store.order?.traceID]);

    React.useEffect(() => {
        if (store.fetchingFrameCandidatesError) {
            enqueueSnackbar(store.fetchingFrameCandidatesError, {variant: 'error'});
        }
    }, [enqueueSnackbar, store.fetchingFrameCandidatesError]);

    let text = t`Looking for frames...`;
    if(store.fetchingFrameTrace) {
        text = t`Loading trace data...`
    }
    return <LoadingOverlay
        active={store.fetchingFrameCandidates || store.fetchingFrameTrace}
        text={text}
        spinner
    >
        {fetchingFrameCandidatesError && <FormHelperText error>{fetchingFrameCandidatesError}</FormHelperText>}
        {fetchingFrameTraceError && <FormHelperText error>{fetchingFrameTraceError}</FormHelperText>}
        <ReadonlyProvider value={store.shouldLockFrameFields}>
            {children}
        </ReadonlyProvider>
    </LoadingOverlay>
});