import * as React from 'react';
import {observer} from "mobx-react-lite";
import {useStockOrderStore} from "../../hooks/useStockOrderStore";
import {Dialog, DialogActions, DialogContent, DialogTitle, Grid} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import {ButtonField, ModelForm, ModelInput} from "@rx-suite/ui";

export const StockItemEditDialog: React.FunctionComponent = observer(() => {
    const store = useStockOrderStore();

    const onClose = React.useCallback(() => {
        store.hideStockItemEditDialog();
        store.resetStockItem();
    }, [])

    return (
        <Dialog open={store.showingStockItemEditDialog} fullWidth>
            <DialogTitle>
                <Trans>Modify Stock Item</Trans>
            </DialogTitle>
            <DialogContent>
                <Grid container spacing={2}>
                    <Grid item xs={12}>
                        <ModelForm model={store.stockItem} suppressWrapper suppressRedirect suppressList suppressImportExport suppressMakeCopy submitText={t`Update Line`} showServerErrorTop={false} afterSubmit={onClose}>
                            <Grid container spacing={2}>
                                <Grid item xs={12}>
                                    <ModelInput name={'description'} disabled/>
                                </Grid>
                                <Grid item xs={12}>
                                    <ModelInput name={'item_identifier'} disabled/>
                                </Grid>
                                <Grid item xs={12}>
                                    <ModelInput name={'item_type'} disabled/>
                                </Grid>
                                <Grid item xs={12}>
                                    <ModelInput name={'quantity'} type={"number"}/>
                                </Grid>
                            </Grid>
                        </ModelForm>
                    </Grid>
                </Grid>
            </DialogContent>
            <DialogActions>
                <ButtonField text={t`Close`} onClick={onClose}/>
            </DialogActions>
        </Dialog>
    );
})