import * as React from 'react';
import {BreadModel, CheckboxField, makeColumn, ModelTableDeleteButton} from "@rx-suite/ui";
import {StockOrderModel, StockOrderStore} from "../../stores/StockOrderStore";
import {StockOrderForm} from "./StockOrderForm";
import {t} from "@lingui/macro";
import {OrdersTabs} from "../OrdersTabs";
import moment from "moment";
import {customerSelectionStore, useCustomerSelectionStore} from "../../hooks/useCustomerSelectionStore";
import {Filter} from "react-table";
import {Box} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {DataStore} from "@rx-suite/data/build";
import {Model} from "@rx-suite/data";
import {OrderModel} from "../../stores/OrderStore";

export const overrideTableMemory = (allAccounts: boolean, store: DataStore<OrderModel> | DataStore<StockOrderModel>) => {
    const customerFilter = store.fetchParams.filtered.find(filter => filter.id === "customer_id")
    if(allAccounts) {
        const value = customerSelectionStore.userCustomers.map(c => c.getId()).join("|")
        if(customerFilter) {
            customerFilter.value = value;
        }
    } else {
        if(customerFilter) {
            customerFilter.value = customerSelectionStore.currentCustomerId;
        }
    }
}
export const StockOrdersBreadModel = observer(() => {
    const [allAccounts, setAllAccounts] = React.useState(false);
    const customerSelectionStore = useCustomerSelectionStore();
    const [defaultFiltered, setDefaultFiltered] = React.useState<Array<Filter>>([{id: 'customer_id', value: customerSelectionStore.currentCustomerId}]);

    const handleAllAccountsChange = React.useCallback(e => {
        setAllAccounts(e.target.checked);
    }, [setAllAccounts]);

    const dateFormat = (value: any) => {
        if (value) {
            return moment(value).format("YYYY-MM-DD")
        }

        return ""
    }
    const columns = React.useMemo(() => [
        makeColumn('order_number', t`Order Number`, "string"),
        makeColumn('po_number', t`PO Number`, "string"),
        makeColumn('reference_number', t`Reference Number`, "string"),
        makeColumn('shipping_method_code', t`Shipping Method`, "string"),
        makeColumn('date_completed', t`Date Completed`, "date", dateFormat),
        makeColumn('date_ordered', t`Date Ordered`, "date", dateFormat),
    ], [])

    React.useEffect(() => {
        const filter = [];

        overrideTableMemory(allAccounts, StockOrderStore);
        if(allAccounts) {
            filter.push({id: 'customer_id', value: customerSelectionStore.userCustomers.map(c => c.getId()).join("|")})
        } else {
            filter.push({id: 'customer_id', value: customerSelectionStore.currentCustomerId})
        }

        setDefaultFiltered(filter);
    }, [allAccounts, customerSelectionStore.currentCustomerId])

    return(
        <>
            <OrdersTabs />
            <BreadModel
                columns={columns}
                store={StockOrderStore}
                Form={StockOrderForm}
                mountEdit={false}
                tableProps={{
                    rememberFetchParams: false,
                    replacementActions: {
                        Delete: ({model: modelIn, store: storeIn}) => {
                            if ((modelIn as StockOrderModel).isOpen) return <ModelTableDeleteButton store={storeIn} model={modelIn}/>;
                            return null;
                        }
                    },
                    defaultFiltered,
                    preTableActions: <Box marginLeft={2}>
                        <CheckboxField
                            label={t`Include All Accounts?`}
                            onChange={handleAllAccountsChange}
                            checked={allAccounts}
                        />
                    </Box>
                }}
            />
        </>
    )
});
