import {attribute, DataStore, model, Model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import {computed, override, reaction} from "mobx";
import {currentUserCan, CurrentUserStore} from "@rx-suite/stores";

@model({
    transportLayer: "/api/config",
    permissionTarget: "config",
    routingInfo: {
        list: '/config',
        update: '/config/:id/edit',
        read: '/config/:id/read',
    }
})

export class ConfigModel extends Model {
    @attribute({label: t`User Id`, id: true})
    user_id = "";

    @attribute({label: t`User Name`})
    user_name = "";

    @attribute({label: t`User Email`})
    user_email = "";

    @attribute({label: t`Default PD`})
    pd = "";

    @attribute({label: t`Default Job Type`})
    default_job_type = "";

    @attribute({label: t`Default Frame Status`})
    default_frame_status = "";

    @attribute({label: t`Edge lens to Frame default`})
    edge_frame = false;

    @attribute({label: t`Last Known Customer`})
    last_known_customer_id = "";

    @attribute({label: t`Continuous Order Entry`})
    continuous_entry = false;

    @attribute({ label: t`Allow Personalization`, description: t`If enabled, displays the blank overrides, personalization 1, and personalization 2 fields when creating an order` })
    allow_personalization = true;

    @attribute({label: t`Customer`})
    customer_ids: string[] = [];

    @attribute({label: t`Select Order Columns`})
    selected_order_columns: string[] = [];

    @attribute({ label: t`Show Confirmation` })
    show_confirmation = false;

    @attribute({ label: t`Quick Codes Only` })
    quick_codes_only = false;

    constructor() {
        super();
        super.setup();
    }

    @override
    get isUserReadable() {
        return (currentUserCan('Config', 'user_config_admin') || (!!CurrentUserStore.selectedModel && (this.user_id.toString() === CurrentUserStore.selectedModel.getId().toString())))
    }

    @override
    get isUserUpdatable() {
        return (currentUserCan('Config', 'user_config_admin') || (!!CurrentUserStore.selectedModel && (this.user_id.toString() === CurrentUserStore.selectedModel.getId().toString())))
    }

    get isQuickCodeOnly(){
        return this.quick_codes_only
    }

}

export const ConfigStore = ConfigModel.store as unknown as DataStore<ConfigModel>;

reaction(() => {
        return CurrentUserStore.selectedModel?.getId();
    },
    () => {
        if (CurrentUserStore.selectedModel) {
            ConfigStore.fetchOne(CurrentUserStore.selectedModel!.getId())
        }
    });

export const CurrentUserConfig = computed(function () {
    const user = CurrentUserStore.selectedModel;
    if (user) {
        return ConfigStore.models.find(m => {
            return m.user_id?.toString() === user.getId().toString();
        }) as ConfigModel || new ConfigModel();
    } else {
        return new ConfigModel();
    }
});

