class SyncLensesJob < ApplicationJob
  def perform
    StockLensSyncStatus.wrap do
      offset = 0

      # Variable to hold the last response
      last_response = nil
      lens_ids = []

      loop do
        lenses = RxModule::Communicator.call_module_method('rx_universe_api', 'api/rxsite/stockfinished', 'get', {
          limit: SyncStatus::LIMIT,
          offset: offset
        })

        break if lenses.empty? || lenses == last_response

        data = lenses[:models].map do
          {
            stock_number: _1[:stockNum],
            manufacturer_code: _1[:manufCode],
            manufacturer_desc: _1[:manufDesc],
            lens_code: _1[:lensCode],
            lens_desc: _1[:lensDesc],
            material_code: _1[:materialCode],
            material_desc: _1[:materialDesc],
            tint_code: _1[:tintCode],
            tint_desc: _1[:tintDesc],
            pretreatment_code: _1[:pretreatmentCode],
            pretreatment_desc: _1[:pretreatmentDesc],
            thick_code: _1[:thickCode],
            sph: _1[:Sph],
            cyl: _1[:Cyl],
            add: _1[:Add],
            dia: _1[:Dia],
            rt_opc: _1[:rtOPC],
            lt_opc: _1[:ltOPC],
            active: true
          }
        end
        StockLens.quietly do
          data.each do |l|
            lens = StockLens.unscope(:where).where(stock_number: l[:stock_number]).first_or_initialize
            lens.assign_attributes(l)
            lens.save
            lens_ids << lens.id
          end
        end
        # Increment the offset ahead of the next loop
        offset += SyncStatus::LIMIT
        # Store the current response as the last response
        last_response = lenses
      end

      StockLens.where.not(id: lens_ids).update_all(active: false, updated_at: Time.now)
    end
  end
end