# == Schema Information
#
# Table name: configs
#
#  id                     :bigint           not null, primary key
#  active                 :boolean          default(TRUE)
#  allow_personalization  :boolean          default(TRUE), not null
#  continuous_entry       :boolean          default(FALSE)
#  default_frame_status   :string(4000)     default("U"), not null
#  default_job_type       :string(4000)
#  edge_frame             :boolean
#  pd                     :string(4000)
#  quick_codes_only       :boolean          default(FALSE), not null
#  selected_order_columns :text(2147483647)
#  show_confirmation      :boolean
#  user_email             :string(4000)
#  user_name              :string(4000)
#  created_at             :datetime         not null
#  updated_at             :datetime         not null
#  last_known_customer_id :string(4000)
#  user_id                :string(4000)
#
class Config < ApplicationRecord
  scope :active, -> { where(active: true) }

  default_scope { active }

  after_initialize :set_defaults

  has_many :config_customers, dependent: :destroy
  has_many :customers, through: :config_customers

  serialize :selected_order_columns, Array


  class << self
    def display_name
      "User Config"
    end
  end

  before_create do
    self.quick_codes_only = true if RxuVersion.instance.va?
  end

  def set_defaults
    self.pd ||= "B"
    self.default_job_type ||= "P"
    self.default_frame_status ||= "U"
    self.edge_frame ||= false
    if selected_order_columns.blank?
      self.selected_order_columns = ["order_number", "customer_name", "release_number", "tray", "_fstatus", "job_track_station", "job_track_description", "date_received", "submitted_by"]
    end
  end

  def to_json(*args)
    JSON.generate(JSON.parse(super.as_json(*args)).merge(JSON.parse(render_jbuilder_partial)))
  end
end
