# == Schema Information
#
# Table name: quick_codes
#
#  id                :bigint           not null, primary key
#  code              :integer          not null
#  created_at        :datetime         not null
#  updated_at        :datetime         not null
#  style_id          :bigint           not null
#  style_material_id :bigint           not null
#  style_type_id     :bigint           not null
#
# Indexes
#
#  index_quick_codes_on_style_id           (style_id)
#  index_quick_codes_on_style_material_id  (style_material_id)
#  index_quick_codes_on_style_type_id      (style_type_id)
#  quick_codes_index                       (style_id,style_material_id,style_type_id) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (style_id => styles.id)
#  fk_rails_...  (style_material_id => style_materials.id)
#  fk_rails_...  (style_type_id => style_types.id)
#
class QuickCode < ApplicationRecord
  validates :code, uniqueness: true, presence: true, numericality: {only_integer: true, greater_than: 0, less_than: 99999999999}
  validate :unique_quick_code

  belongs_to :style_type
  belongs_to :style_material
  belongs_to :style

  def self.display_name
    "Quick Codes"
  end

  def unique_quick_code
    quick_code = QuickCode.find_by(style_id: style_id, style_type_id: style_type_id, style_material_id: style_material_id)
    if quick_code && quick_code != self
      errors.add("", "The Quick Code you're trying to create already exists.")
    end
  end

  def to_json(*args)
    render_jbuilder_partial
  rescue
    super(*args)
  end
end
