# == Schema Information
#
# Table name: styles
#
#  id             :bigint           not null, primary key
#  active         :boolean
#  description    :string(4000)
#  requires_trace :boolean
#  style          :string(4000)
#  created_at     :datetime         not null
#  updated_at     :datetime         not null
#  style_type_id  :bigint           not null
#
# Indexes
#
#  index_styles_on_style          (style) UNIQUE
#  index_styles_on_style_type_id  (style_type_id)
#
# Foreign Keys
#
#  fk_rails_...  (style_type_id => style_types.id)
#
class Style < ApplicationRecord
  scope :active, -> { where(active: true) }

  default_scope { active }

  validates_uniqueness_of :style

  belongs_to :style_type
  has_many :style_types
  has_many :quick_codes

  after_save { quick_codes.touch_all }

  class << self
    def find_or_load(code)
      the_style = Style.unscoped.find_by(style: code)
      unless the_style
        resp = RxModule::Communicator::Rxuniverse.lookup_style(code)
        the_style_type = StyleType.unscoped.find_or_create_by(style_type: resp[:typeDesc])
        the_style = Style.create({
          style: resp[:code],
          description: resp[:description],
          style_type: the_style_type
        })
      end
      the_style
    end
  end
end
